# Generated by Django 2.2 on 2019-09-26 13:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mds', '0051_fill_compliance_lag'),
    ]

    operations = [
        migrations.AlterField(
            model_name='compliance',
            name='lag',
            field=models.DurationField(),
        ),
    ]
