# Generated by Django 2.1.5 on 2019-09-25 10:11

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('mds', '0048_add_compliance_lag'),
    ]

    operations = [
        migrations.AddField(
            model_name='policy',
            name='config',
            field=django.contrib.postgres.fields.jsonb.JSONField(default=dict),
        ),
    ]
