# Generated by Django 2.2 on 2019-09-26 12:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("mds", "0047_add_daily_penalty_20190924_0933")]

    operations = [
        migrations.AddField(
            model_name="compliance",
            name="lag",
            field=models.DurationField(blank=True, null=True),
        ),
        migrations.AlterUniqueTogether(
            name="compliance",
            unique_together={
                ("policy", "rule", "geography", "vehicle", "start_date", "lag")
            },
        ),
        # Not related but forgot about that
        migrations.AlterField(
            model_name="compliance", name="geography", field=models.UUIDField()
        ),
        migrations.AlterField(
            model_name="compliance", name="rule", field=models.UUIDField()
        ),
    ]
