# Generated by Django 2.2.5 on 2019-09-24 09:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mds', '0046_compliance_uniqueness'),
    ]

    operations = [
        migrations.AddField(
            model_name='policy',
            name='daily_penalty',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='compliance',
            name='geography',
            field=models.UUIDField(),
        ),
        migrations.AlterField(
            model_name='compliance',
            name='rule',
            field=models.UUIDField(),
        ),
    ]
