# Generated by Django 2.2 on 2019-09-26 13:05
import datetime

from django.db import migrations


def fill_compliance_lag(apps, schema_editor):
    Compliance = apps.get_model("mds", "Compliance")
    # The default value on compliances already computed
    Compliance.objects.update(lag=datetime.timedelta(0))


class Migration(migrations.Migration):

    dependencies = [("mds", "0050_pre_migrate_to_policy_config")]

    operations = [migrations.RunPython(fill_compliance_lag, migrations.RunPython.noop)]
