# Generated by Django 2.1.5 on 2019-09-25 10:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('mds', '0052_required_compliance_lag'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='policy',
            name='daily_penalty',
        ),
        migrations.RemoveField(
            model_name='policy',
            name='fixed_price',
        ),
    ]
